"""
bitstillery_pyi18next - A Python implementation of i18next with pluralisation fixes.

This is a fork of pyi18next that fixes pluralisation count issues.
"""
__author__ = "Gongziting Tech Ltd., Bitstillery"

from .i18next import I18next

__all__ = ["I18next"]
